@@ -8,8 +8,10 @@ import {SnapshotError, VersionMismatchError} from './snapshot-manager.js';
 
 function formatDescriptorDiff(actualDescriptor, expectedDescriptor, options) {
 	options = {...options, ...concordanceOptions};
+	const {diffGutters} = options.theme;
+	const {insertLine, deleteLine} = options.theme.string.diff;
 	return {
-		label: 'Difference:',
+		label: `Difference (${diffGutters.actual}${deleteLine.open}actual${deleteLine.close}, ${diffGutters.expected}${insertLine.open}expected${insertLine.close}):`,
 		formatted: concordance.diffDescriptors(actualDescriptor, expectedDescriptor, options),
 	};
 }
