@@ -29,17 +29,13 @@ const loadConfigFile = async ({projectDir, configFile}) => {
 			return null;
 		}
 
-		throw Object.assign(new Error(`Error loading ${fileForErrorMessage}: ${error.message}`), {parent: error});
+		throw Object.assign(new Error(`Error loading ${fileForErrorMessage}: ${error.message}`), {cause: error});
 	}
 };
 
 function resolveConfigFile(configFile) {
 	if (configFile) {
 		configFile = path.resolve(configFile); // Relative to CWD
-
-		if (!configFile.endsWith('.js') && !configFile.endsWith('.cjs') && !configFile.endsWith('.mjs')) {
-			throw new Error('Config files must have .js, .cjs or .mjs extensions');
-		}
 	}
 
 	return configFile;
@@ -78,7 +74,7 @@ async function checkJsonFile(searchDir) {
 	}
 }
 
-export async function loadConfig({configFile, resolveFrom = process.cwd(), defaults = {}} = {}) {
+export async function loadConfig({configFile, resolveFrom = process.cwd(), defaults = {}} = {}) { // eslint-disable-line complexity
 	let packageConf = await packageConfig('ava', {cwd: resolveFrom});
 	const filepath = packageJsonPath(packageConf);
 	const projectDir = filepath === undefined ? resolveFrom : path.dirname(filepath);
@@ -94,7 +90,17 @@ export async function loadConfig({configFile, resolveFrom = process.cwd(), defau
 	let fileForErrorMessage;
 	let conflicting = [];
 	if (configFile) {
-		const loaded = await loadConfigFile({projectDir, configFile});
+		let loaded;
+		try {
+			loaded = await loadConfigFile({projectDir, configFile});
+		} catch (error) {
+			if (!configFile.endsWith('.js') && !configFile.endsWith('.cjs') && !configFile.endsWith('.mjs')) {
+				throw Object.assign(new Error('Could not load config file; it should have .js, .cjs or .mjs extension'), {cause: error});
+			}
+
+			throw error;
+		}
+
 		if (loaded !== null) {
 			({config: fileConf, fileForErrorMessage} = loaded);
 		}
