@@ -9,6 +9,7 @@ export default class RunStatus extends Emittery {
 		super();
 
 		this.pendingTests = new Map();
+		this.pendingTestsLogs = new Map();
 
 		this.emptyParallelRun = parallelRuns
 			&& parallelRuns.currentFileCount === 0
@@ -60,6 +61,7 @@ export default class RunStatus extends Emittery {
 		});
 
 		this.pendingTests.set(testFile, new Set());
+		this.pendingTestsLogs.set(testFile, new Map());
 		worker.onStateChange(data => this.emitStateChange(data));
 	}
 
@@ -124,10 +126,15 @@ export default class RunStatus extends Emittery {
 				fileStats.remainingTests--;
 				this.removePendingTest(event);
 				break;
+			case 'test-register-log-reference':
+				this.addPendingTestLogs(event);
+				break;
 			case 'timeout':
 				stats.timeouts++;
 				event.pendingTests = this.pendingTests;
+				event.pendingTestsLogs = this.pendingTestsLogs;
 				this.pendingTests = new Map();
+				this.pendingTestsLogs = new Map();
 				for (const testsInFile of event.pendingTests.values()) {
 					stats.timedOutTests += testsInFile.size;
 				}
@@ -135,11 +142,15 @@ export default class RunStatus extends Emittery {
 				break;
 			case 'interrupt':
 				event.pendingTests = this.pendingTests;
+				event.pendingTestsLogs = this.pendingTestsLogs;
 				this.pendingTests = new Map();
+				this.pendingTestsLogs = new Map();
 				break;
 			case 'process-exit':
 				event.pendingTests = this.pendingTests;
+				event.pendingTestsLogs = this.pendingTestsLogs;
 				this.pendingTests = new Map();
+				this.pendingTestsLogs = new Map();
 				break;
 			case 'uncaught-exception':
 				stats.uncaughtExceptions++;
@@ -198,6 +209,10 @@ export default class RunStatus extends Emittery {
 		return 0;
 	}
 
+	addPendingTestLogs(event) {
+		this.pendingTestsLogs.get(event.testFile)?.set(event.title, event.logs);
+	}
+
 	addPendingTest(event) {
 		if (this.pendingTests.has(event.testFile)) {
 			this.pendingTests.get(event.testFile).add(event.title);
