@@ -56,7 +56,7 @@ function assertFailure(t, subset) {
 	if (subset.values) {
 		t.equal(lastFailure.values.length, subset.values.length);
 		for (const [i, s] of lastFailure.values.entries()) {
-			t.equal(s.label, subset.values[i].label);
+			t.equal(stripAnsi(s.label), subset.values[i].label);
 			t.match(stripAnsi(s.formatted), subset.values[i].formatted);
 		}
 	} else {
@@ -279,7 +279,7 @@ test('.is()', t => {
 		message: '',
 		raw: {actual: 'foo', expected: 'bar'},
 		values: [
-			{label: 'Difference:', formatted: /- 'foo'\n\+ 'bar'/},
+			{label: 'Difference (- actual, + expected):', formatted: /- 'foo'\n\+ 'bar'/},
 		],
 	});
 
@@ -289,7 +289,7 @@ test('.is()', t => {
 		expected: 42,
 		message: '',
 		values: [
-			{label: 'Difference:', formatted: /- 'foo'\n\+ 42/},
+			{label: 'Difference (- actual, + expected):', formatted: /- 'foo'\n\+ 42/},
 		],
 	});
 
@@ -297,7 +297,7 @@ test('.is()', t => {
 		assertion: 'is',
 		message: 'my message',
 		values: [
-			{label: 'Difference:', formatted: /- 'foo'\n\+ 42/},
+			{label: 'Difference (- actual, + expected):', formatted: /- 'foo'\n\+ 42/},
 		],
 	});
 
@@ -305,7 +305,7 @@ test('.is()', t => {
 		assertion: 'is',
 		message: 'my message',
 		values: [
-			{label: 'Difference:', formatted: /- 0\n\+ -0/},
+			{label: 'Difference (- actual, + expected):', formatted: /- 0\n\+ -0/},
 		],
 	});
 
@@ -313,7 +313,7 @@ test('.is()', t => {
 		assertion: 'is',
 		message: 'my message',
 		values: [
-			{label: 'Difference:', formatted: /- -0\n\+ 0/},
+			{label: 'Difference (- actual, + expected):', formatted: /- -0\n\+ 0/},
 		],
 	});
 
@@ -535,20 +535,20 @@ test('.deepEqual()', t => {
 		assertion: 'deepEqual',
 		message: '',
 		raw: {actual: 'foo', expected: 'bar'},
-		values: [{label: 'Difference:', formatted: /- 'foo'\n\+ 'bar'/}],
+		values: [{label: 'Difference (- actual, + expected):', formatted: /- 'foo'\n\+ 'bar'/}],
 	});
 
 	failsWith(t, () => assertions.deepEqual('foo', 42), {
 		assertion: 'deepEqual',
 		message: '',
 		raw: {actual: 'foo', expected: 42},
-		values: [{label: 'Difference:', formatted: /- 'foo'\n\+ 42/}],
+		values: [{label: 'Difference (- actual, + expected):', formatted: /- 'foo'\n\+ 42/}],
 	});
 
 	failsWith(t, () => assertions.deepEqual('foo', 42, 'my message'), {
 		assertion: 'deepEqual',
 		message: 'my message',
-		values: [{label: 'Difference:', formatted: /- 'foo'\n\+ 42/}],
+		values: [{label: 'Difference (- actual, + expected):', formatted: /- 'foo'\n\+ 42/}],
 	});
 
 	failsWith(t, () => assertions.deepEqual({}, {}, null), {
@@ -758,7 +758,7 @@ test('.like()', t => {
 	failsWith(t, () => assertions.like({a: 'foo', b: 'irrelevant'}, {a: 'bar'}), {
 		assertion: 'like',
 		message: '',
-		values: [{label: 'Difference:', formatted: /{\n-\s*a: 'foo',\n\+\s*a: 'bar',\n\s*}/}],
+		values: [{label: 'Difference (- actual, + expected):', formatted: /{\n-\s*a: 'foo',\n\+\s*a: 'bar',\n\s*}/}],
 	});
 
 	t.end();
@@ -1429,7 +1429,7 @@ test('.snapshot()', async t => {
 		failsWith(t, () => assertions.snapshot({foo: 'not bar'}), {
 			assertion: 'snapshot',
 			message: 'Did not match snapshot',
-			values: [{label: 'Difference:', formatted: '  {\n-   foo: \'not bar\',\n+   foo: \'bar\',\n  }'}],
+			values: [{label: 'Difference (- actual, + expected):', formatted: '  {\n-   foo: \'not bar\',\n+   foo: \'bar\',\n  }'}],
 		});
 	}
 
@@ -1442,7 +1442,7 @@ test('.snapshot()', async t => {
 		failsWith(t, () => assertions.snapshot({foo: 'not bar'}, 'my message'), {
 			assertion: 'snapshot',
 			message: 'my message',
-			values: [{label: 'Difference:', formatted: '  {\n-   foo: \'not bar\',\n+   foo: \'bar\',\n  }'}],
+			values: [{label: 'Difference (- actual, + expected):', formatted: '  {\n-   foo: \'not bar\',\n+   foo: \'bar\',\n  }'}],
 		});
 	}
 
